/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var BioMaterialEvents = function()
{
	var biomaterialevents = {};
	
	/**
		Initialize the page.
	*/
	biomaterialevents.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', biomaterialevents.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabValidator('settings.info', biomaterialevents.validateEvent);
			
			// Protocol
			Buttons.addClickHandler('protocol_id.select', biomaterialevents.selectProtocol);
			Events.addEventHandler('protocol_id', 'base-selected', biomaterialevents.setProtocolCallback);
			
			// Used quantity
			Events.addEventHandler('usedQuantity', 'keypress', Events.numberOnly);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'BIOMATERIALEVENT', 'item-id': itemId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'BIOMATERIALEVENT'};
			var tableAttributes = {'table-id': 'events'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
			
			TabControl.setSwitchFunction('main', biomaterialevents.switchTab);
		}
	}
	
	biomaterialevents.switchTab = function(event)
	{
		var target = event.target;
		var tabId = target.id.substring(5);

		var frm = document.forms['events'];
		var bioMaterialId = frm.biomaterial_id.value;
		var bioMaterialType = frm.biomaterial_type.value;

		var url = App.getRoot()+Items.getController(bioMaterialType).url + '?ID='+App.getSessionId();
		url += '&cmd=ViewItem&item_id='+bioMaterialId;
		url += '&tab='+tabId;
		location.replace(url);
	}
	
	biomaterialevents.validateEvent = function()
	{
		var frm = document.forms['event'];
		return true;
	}

	// Submit the form
	biomaterialevents.save = function()
	{
		var frm = document.forms['event'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}
	
	biomaterialevents.selectProtocol = function()
	{
		var frm = document.forms['event'];
		var url = '';
		if (frm.protocol_id.length > 1) 
		{
			var id = Math.abs(parseInt(frm.protocol_id[1].value));				
			url += '&item_id='+id;
		}
		Dialogs.selectItem('PROTOCOL', 'protocol_id', 0, url);
	}
	
	biomaterialevents.setProtocolCallback = function(event)
	{
		var id = event.detail.id;
		var name = event.detail.name;
		var frm = document.forms['event'];
		var list = frm.protocol_id;
		if (list.length < 2 || list[1].value == '0')
		{
			Forms.addListOption(list, 1, new Option());
		}
		list[1].value = id;
		list[1].text = name;
		list.selectedIndex = 1;
	}

	
	return biomaterialevents;
}();

Doc.onLoad(BioMaterialEvents.initPage);
