<%-- $Id: edit_mapping.jsp 6312 2013-08-28 11:48:06Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------


	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.PlateMapping"
	import="net.sf.basedb.core.PlateGeometry"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.BaseException"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.List"
	import="java.util.Set"
	import="java.util.HashSet"
	import="java.util.Date"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%
final Item itemType = Item.PLATEMAPPING;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	String title = null;
	PlateMapping mapping = null;
	ItemResultList<PlateGeometry> plateGeometries = null;
	
	boolean readCurrentSourceGeometry = true;
	PlateGeometry currentSourceGeometry = null;
	int currentSourceGeometryId = 0;
	
	boolean readCurrentDestinationGeometry = true;
	PlateGeometry currentDestinationGeometry = null;
	int currentDestinationGeometryId = 0;
	
	if (itemId == 0)
	{
		title = "Create plate mapping";
		cc.removeObject("item");
		
		ItemQuery<PlateGeometry> geometryQuery = PlateGeometry.getQuery();
		geometryQuery.order(Orders.asc(Hql.property("name")));
		geometryQuery.setCacheResult(true);

		plateGeometries = geometryQuery.list(dc);
		currentSourceGeometryId = Values.getInt(cc.getPropertyValue("sourceGeometry"), 0);
		currentDestinationGeometryId = Values.getInt(cc.getPropertyValue("destinationGeometry"), 0);
	}
	else
	{
		mapping = PlateMapping.getById(dc, itemId);
		mapping.checkPermission(Permission.WRITE);
		cc.setObject("item", mapping);
		title = "Edit plate mapping -- " + HTML.encodeTags(mapping.getName());
		
		try
		{
			currentSourceGeometry = mapping.getSourceGeometry();
		}
		catch (PermissionDeniedException ex)
		{
			readCurrentSourceGeometry = false;
		}
		try
		{
			currentDestinationGeometry = mapping.getDestinationGeometry();
		}
		catch (PermissionDeniedException ex)
		{
			readCurrentDestinationGeometry = false;
		}
	}
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(itemType), mapping);
	ExtensionsInvoker invoker = EditUtil.useEditExtensions(jspContext);
	%>
	<base:page type="popup" title="<%=title%>" id="edit-page">
	<base:head scripts="tabcontrol-2.js,~mappings.js" styles="tabcontrol.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<h1><%=title%> <base:help tabcontrol="settings" /></h1>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="mapping">
		<input type="hidden" name="cmd" value="UpdateItem">

		<t:tabcontrol id="settings"
			subclass="content dialogtabcontrol"
			position="bottom" remember="<%=mapping != null%>"
			extensions="<%=invoker%>">
		<t:tab id="info" title="Plate mapping" helpid="platemapping.edit">
			<table class="fullform input100 smaller">
			<tr>
				<th>Name</th>
				<td><input class="text required auto-init" data-auto-init="<%=mapping == null ? "focus-select" : "focus" %>"
					type="text" name="name" 
					value="<%=HTML.encodeTags(mapping == null ? Values.getString(cc.getPropertyValue("name"), "New plate mapping") : mapping.getName())%>" 
					maxlength="<%=PlateMapping.MAX_NAME_LENGTH%>"></td>
				<td></td>
			</tr>
			<tr>
				<th>Source plates</th>
				<td>
					<%
					if (mapping == null)
					{
						%>
						<input class="text required" type="text" name="source_count" id="source_count"
							style="width: 15em;" maxlength="10"
							value="<%=Values.getInt(cc.getPropertyValue("sourceCount"), 1)%>">
						plate(s) of
						<select name="sourcegeometry_id" class="required">
						<%
						for (PlateGeometry pg : plateGeometries)
						{
							%>
							<option value="<%=pg.getId()%>" <%=pg.getId() == currentSourceGeometryId ? "selected" : ""%>><%=HTML.encodeTags(pg.getName())%>
							<%
						}
						%>
						</select><br>
						can't be changed later
						<%
					}
					else
					{
						%>
						<%=mapping.getSourceCount()%> plate(s) of 
						<%=Base.getEncodedName(currentSourceGeometry, !readCurrentSourceGeometry)%>
						<%
					}
					%>
				</td>
				<td></td>
			</tr>
			<tr>
				<th>Destination plates</th>
				<td>
					<%
					if (mapping == null)
					{
						%>
						<input class="text required" type="text" name="destination_count" id="destination_count" 
							style="width: 15em;" maxlength="10"
							value="<%=Values.getInt(cc.getPropertyValue("destinationCount"), 1)%>">
						plate(s) of
						<select name="destinationgeometry_id" class="required">
						<%
						for (PlateGeometry pg : plateGeometries)
						{
							%>
							<option value="<%=pg.getId()%>" <%=pg.getId() == currentDestinationGeometryId ? "selected" : ""%>><%=HTML.encodeTags(pg.getName())%>
							<%
						}
						%>
						</select><br>
						can't be changed later
						<%
					}
					else
					{
						%>
						<%=mapping.getDestinationCount()%> plate(s) of 
						<%=Base.getEncodedName(currentDestinationGeometry, !readCurrentDestinationGeometry)%>
						<%
					}
					%>
				</td>
				<td></td>
			</tr>
			<tr class="big">
				<th>Image</th>
				<td>
					<input class="text" type="text" name="image" id="image"
						value="<%=HTML.encodeTags(mapping == null ? "" : mapping.getImage())%>" 
						maxlength="<%=PlateMapping.MAX_IMAGE_LENGTH%>">
						<br><br>
						<%
						String src = "noimage.gif";
						if (mapping != null && mapping.getImage() != null)
						{
							src = mapping.getImage();
						}
						%>
						<img id="mappingImage" src="../../images/platemappings/<%=src%>" alt="">
				</td>
				<td></td>
			</tr>
			<tr class="dynamic">
				<th>Description</th>
				<td>
					<textarea class="text" rows="6" name="description" id="description"
						><%=HTML.encodeTags(mapping == null ? cc.getPropertyValue("description") : mapping.getDescription())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="description" title="Description" />
				</td>
			</tr>
			</table>
		</t:tab>
		</t:tabcontrol>
		</form>
		
		<div class="legend">
			<base:icon image="required.png" />= required information
		</div>

		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
