/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var Plates = function()
{
	var plates = {};
	
	/**
		Initialize the page.
	*/
	plates.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', plates.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabActivateListener('settings.annotations', Annotations.autoLoadEditFrame);
			TabControl.addTabActivateListener('settings.inheritedAnnotations', Annotations.autoLoadInheritFrame);
			TabControl.addTabValidator('settings.info', plates.validatePlate);

			// Plate type
			Buttons.addClickHandler('platetype_id.select', plates.selectPlateType);
			Events.addEventHandler('platetype_id', 'base-selected', plates.setPlateType);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'PLATE', 'item-id': itemId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			
			TabControl.addTabActivateListener('main.annotations', AnnotationsList.loadOnce);
			TabControl.addTabActivateListener('main.history', History.loadOnce);
			TabControl.addTabActivateListener('main.events', plates.viewEvents);
			TabControl.addTabActivateListener('main.wells', plates.viewWells);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'PLATE'};
			var tableAttributes = {'table-id': 'plates'};
			Buttons.addClickHandler('btnMergePlates', plates.mergePlates);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
	
	plates.mergePlates = function()
	{
		Dialogs.openPopup('merge_plates.jsp?ID='+App.getSessionId(), 'MergePlates', 600, 400);
	}
	
	plates.viewEvents = function()
	{
		var plateId = Data.get('page-data', 'item-id');
		var url = 'events/index.jsp?ID='+App.getSessionId();
		url += '&plate_id='+plateId;
		location.replace(url);
	}

	plates.viewWells = function()
	{
		var plateId = Data.get('page-data', 'item-id');
		var url = 'wells/index.jsp?ID='+App.getSessionId();
		url += '&plate_id='+plateId;
		location.replace(url);
	}
	
	plates.validatePlate = function()
	{
		var frm = document.forms['plate'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		if (frm.platetype_id && frm.platetype_id.length == 0)
		{
			Forms.showNotification('platetype_id.select', 'You must select a plate type');
			return false;
		}
		return true;
	}

	// Submit the form
	plates.save = function()
	{
		var frm = document.forms['plate'];
		if (TabControl.validateActiveTab('settings'))
		{
			Annotations.saveModifiedAnnotationsToForm(frm);
			Annotations.saveInheritedAnnotationsToForm(frm);
			frm.submit();
		}
	}


	plates.selectPlateType = function()
	{
		var frm = document.forms['plate'];
		var url = '';
		if (frm.platetype_id.length > 0) 
		{
			url += '&item_id='+frm.platetype_id[0].value;
		}
		Dialogs.selectItem('PLATETYPE', 'platetype_id', 0, url);
	}
	
	plates.setPlateType = function(event)
	{
		var frm = document.forms['plate'];
		if (frm.platetype_id.length < 1)
		{
			frm.platetype_id[frm.platetype_id.length] = new Option();
		}
		frm.platetype_id[0].value = event.detail.id;
		frm.platetype_id[0].text = event.detail.name;
		frm.platetype_id.selectedIndex = 0;
	}

	return plates;
}();

Doc.onLoad(Plates.initPage);
